@@ -46,6 +46,9 @@ pub(crate) struct Context {
 
     /// Derives added to event structs and enums.
     event_derives: Vec<Path>,
+
+    /// Manually specified event aliases.
+    event_aliases: BTreeMap<String, Ident>,
 }
 
 impl Context {
@@ -77,6 +80,10 @@ impl Context {
         // 5. Declare the structs parsed from the human readable abi
         let abi_structs_decl = cx.abi_structs()?;
 
+        let ethers_core = util::ethers_core_crate();
+        let ethers_contract = util::ethers_contract_crate();
+        let ethers_providers = util::ethers_providers_crate();
+
         Ok(quote! {
             // export all the created data types
             pub use #name_mod::*;
@@ -86,12 +93,12 @@ impl Context {
                 #imports
                 #struct_decl
 
-                impl<'a, M: ethers_providers::Middleware> #name<M> {
+                impl<'a, M: #ethers_providers::Middleware> #name<M> {
                     /// Creates a new contract instance with the specified `ethers`
                     /// client at the given `Address`. The contract derefs to a `ethers::Contract`
                     /// object
-                    pub fn new<T: Into<ethers_core::types::Address>>(address: T, client: ::std::sync::Arc<M>) -> Self {
-                        let contract = ethers_contract::Contract::new(address.into(), #abi_name.clone(), client);
+                    pub fn new<T: Into<#ethers_core::types::Address>>(address: T, client: ::std::sync::Arc<M>) -> Self {
+                        let contract = #ethers_contract::Contract::new(address.into(), #abi_name.clone(), client);
                         Self(contract)
                     }
 
@@ -147,6 +154,12 @@ impl Context {
             }
         }
 
+        let mut event_aliases = BTreeMap::new();
+        for (signature, alias) in args.event_aliases.into_iter() {
+            let alias = syn::parse_str(&alias)?;
+            event_aliases.insert(signature, alias);
+        }
+
         let event_derives = args
             .event_derives
             .iter()
@@ -163,6 +176,7 @@ impl Context {
             contract_name,
             method_aliases,
             event_derives,
+            event_aliases,
         })
     }
 }
