@@ -56,30 +56,33 @@ impl Context {
         let variants = sorted_events
             .values()
             .flatten()
-            .map(expand_struct_name)
+            .map(|e| expand_struct_name(e, self.event_aliases.get(&e.abi_signature()).cloned()))
             .collect::<Vec<_>>();
 
         let enum_name = self.expand_event_enum_name();
 
+        let ethers_core = util::ethers_core_crate();
+        let ethers_contract = util::ethers_contract_crate();
+
         quote! {
             #[derive(Debug, Clone, PartialEq, Eq)]
             pub enum #enum_name {
                 #(#variants(#variants)),*
             }
 
-             impl ethers_core::abi::Tokenizable for #enum_name {
+             impl #ethers_core::abi::Tokenizable for #enum_name {
 
-                 fn from_token(token: ethers_core::abi::Token) -> Result<Self, ethers_core::abi::InvalidOutputType> where
+                 fn from_token(token: #ethers_core::abi::Token) -> Result<Self, #ethers_core::abi::InvalidOutputType> where
                      Self: Sized {
                     #(
                         if let Ok(decoded) = #variants::from_token(token.clone()) {
                             return Ok(#enum_name::#variants(decoded))
                         }
                     )*
-                    Err(ethers_core::abi::InvalidOutputType("Failed to decode all event variants".to_string()))
+                    Err(#ethers_core::abi::InvalidOutputType("Failed to decode all event variants".to_string()))
                 }
 
-                fn into_token(self) -> ethers_core::abi::Token {
+                fn into_token(self) -> #ethers_core::abi::Token {
                     match self {
                         #(
                             #enum_name::#variants(element) => element.into_token()
@@ -87,10 +90,10 @@ impl Context {
                     }
                 }
              }
-             impl ethers_core::abi::TokenizableItem for #enum_name { }
+             impl #ethers_core::abi::TokenizableItem for #enum_name { }
 
-             impl ethers_contract::EthLogDecode for #enum_name {
-                fn decode_log(log: &ethers_core::abi::RawLog) -> Result<Self, ethers_core::abi::Error>
+             impl #ethers_contract::EthLogDecode for #enum_name {
+                fn decode_log(log: &#ethers_core::abi::RawLog) -> Result<Self, #ethers_core::abi::Error>
                 where
                     Self: Sized,
                 {
@@ -99,7 +102,7 @@ impl Context {
                             return Ok(#enum_name::#variants(decoded))
                         }
                     )*
-                    Err(ethers_core::abi::Error::InvalidData)
+                    Err(#ethers_core::abi::Error::InvalidData)
                 }
             }
         }
@@ -115,17 +118,21 @@ impl Context {
         let sorted_events: BTreeMap<_, _> = self.abi.events.clone().into_iter().collect();
 
         let mut iter = sorted_events.values().flatten();
+        let ethers_contract = util::ethers_contract_crate();
 
         if let Some(event) = iter.next() {
             let ty = if iter.next().is_some() {
                 self.expand_event_enum_name()
             } else {
-                expand_struct_name(event)
+                expand_struct_name(
+                    event,
+                    self.event_aliases.get(&event.abi_signature()).cloned(),
+                )
             };
 
             quote! {
-                /// Returns an [`Event`](ethers_contract::builders::Event) builder for all events of this contract
-                pub fn events(&self) -> ethers_contract::builders::Event<M, #ty> {
+                /// Returns an [`Event`](#ethers_contract::builders::Event) builder for all events of this contract
+                pub fn events(&self) -> #ethers_contract::builders::Event<M, #ty> {
                     self.0.event_with_filter(Default::default())
                 }
             }
@@ -142,6 +149,8 @@ impl Context {
     /// If a complex types matches with a struct previously parsed by the AbiParser,
     /// we can replace it
     fn expand_input_type(&self, input: &EventParam) -> Result<TokenStream> {
+        let ethers_core = util::ethers_core_crate();
+
         Ok(match (&input.kind, input.indexed) {
             (ParamType::Array(ty), true) => {
                 if let ParamType::Tuple(..) = **ty {
@@ -156,7 +165,7 @@ impl Context {
                         return Ok(quote! {::std::vec::Vec<#ty>});
                     }
                 }
-                quote! { ethers_core::types::H256 }
+                quote! { #ethers_core::types::H256 }
             }
             (ParamType::FixedArray(ty, size), true) => {
                 if let ParamType::Tuple(..) = **ty {
@@ -172,7 +181,7 @@ impl Context {
                         return Ok(quote! {[#ty; #size]});
                     }
                 }
-                quote! { ethers_core::types::H256 }
+                quote! { #ethers_core::types::H256 }
             }
             (ParamType::Tuple(..), true) => {
                 // represents an struct
@@ -185,11 +194,11 @@ impl Context {
                 {
                     quote! {#ty}
                 } else {
-                    quote! { ethers_core::types::H256 }
+                    quote! { #ethers_core::types::H256 }
                 }
             }
             (ParamType::Bytes, true) | (ParamType::String, true) => {
-                quote! { ethers_core::types::H256 }
+                quote! { #ethers_core::types::H256 }
             }
             (kind, _) => types::expand(kind)?,
         })
@@ -213,16 +222,24 @@ impl Context {
 
     /// Expands into a single method for contracting an event stream.
     fn expand_filter(&self, event: &Event) -> TokenStream {
+        let ethers_contract = util::ethers_contract_crate();
+        let alias = self.event_aliases.get(&event.abi_signature()).cloned();
+
+        let name = if let Some(id) = alias.clone() {
+            util::safe_ident(&format!("{}_filter", id.to_string().to_snake_case()))
+        } else {
+            util::safe_ident(&format!("{}_filter", event.name.to_snake_case()))
+        };
+
         // append `filter` to disambiguate with potentially conflicting
         // function names
-        let name = util::safe_ident(&format!("{}_filter", event.name.to_snake_case()));
-        // let result = util::ident(&event.name.to_pascal_case());
-        let result = expand_struct_name(event);
+
+        let result = expand_struct_name(event, alias);
 
         let doc = util::expand_doc(&format!("Gets the contract's `{}` event", event.name));
         quote! {
             #doc
-            pub fn #name(&self) -> ethers_contract::builders::Event<M, #result> {
+            pub fn #name(&self) -> #ethers_contract::builders::Event<M, #result> {
                 self.0.event()
             }
         }
@@ -232,7 +249,11 @@ impl Context {
     /// into a structure or a tuple in the case where all event parameters (topics
     /// and data) are anonymous.
     fn expand_event(&self, event: &Event) -> Result<TokenStream> {
-        let event_name = expand_struct_name(event);
+        let sig = self.event_aliases.get(&event.abi_signature()).cloned();
+        let abi_signature = event.abi_signature();
+        let event_abi_name = event.name.clone();
+
+        let event_name = expand_struct_name(event, sig);
 
         let params = self.expand_params(event)?;
         // expand as a tuple if all fields are anonymous
@@ -244,11 +265,11 @@ impl Context {
         };
 
         let derives = expand_derives(&self.event_derives);
-        let abi_signature = event.abi_signature();
-        let event_abi_name = &event.name;
+
+        let ethers_contract = util::ethers_contract_crate();
 
         Ok(quote! {
-            #[derive(Clone, Debug, Default, Eq, PartialEq, ethers_contract::EthEvent, #derives)]
+            #[derive(Clone, Debug, Default, Eq, PartialEq, #ethers_contract::EthEvent, #derives)]
             #[ethevent( name = #event_abi_name, abi = #abi_signature )]
             pub #data_type_definition
         })
@@ -299,9 +320,14 @@ impl Context {
 }
 
 /// Expands an ABI event into an identifier for its event data type.
-fn expand_struct_name(event: &Event) -> Ident {
+fn expand_struct_name(event: &Event, alias: Option<Ident>) -> Ident {
     // TODO: get rid of `Filter` suffix?
-    let name = format!("{}Filter", event.name.to_pascal_case());
+
+    let name = if let Some(id) = alias {
+        format!("{}Filter", id.to_string().to_pascal_case())
+    } else {
+        format!("{}Filter", event.name.to_pascal_case())
+    };
     util::ident(&name)
 }
 
@@ -351,9 +377,10 @@ fn expand_derives(derives: &[Path]) -> TokenStream {
 /// quasi-quoting for code generation. We do this to avoid allocating at runtime
 fn expand_hash(hash: Hash) -> TokenStream {
     let bytes = hash.as_bytes().iter().copied().map(Literal::u8_unsuffixed);
+    let ethers_core = util::ethers_core_crate();
 
     quote! {
-        ethers_core::types::H256([#( #bytes ),*])
+        #ethers_core::types::H256([#( #bytes ),*])
     }
 }
 
@@ -367,6 +394,50 @@ mod tests {
         Context::from_abigen(Abigen::new("TestToken", "[]").unwrap()).unwrap()
     }
 
+    fn test_context_with_alias(sig: &str, alias: &str) -> Context {
+        Context::from_abigen(
+            Abigen::new("TestToken", "[]")
+                .unwrap()
+                .add_event_alias(sig, alias),
+        )
+        .unwrap()
+    }
+
+    #[test]
+    #[rustfmt::skip]
+    fn expand_transfer_filter_with_alias() {
+        let event = Event {
+            name: "Transfer".into(),
+            inputs: vec![
+                EventParam {
+                    name: "from".into(),
+                    kind: ParamType::Address,
+                    indexed: true,
+                },
+                EventParam {
+                    name: "to".into(),
+                    kind: ParamType::Address,
+                    indexed: true,
+                },
+                EventParam {
+                    name: "amount".into(),
+                    kind: ParamType::Uint(256),
+                    indexed: false,
+                },
+            ],
+            anonymous: false,
+        };
+        let sig = "Transfer(address,address,uint256)";
+        let cx = test_context_with_alias(sig, "TransferEvent");
+        assert_quote!(cx.expand_filter(&event), {
+            #[doc = "Gets the contract's `Transfer` event"]
+            pub fn transfer_event_filter(
+                &self
+            ) -> ethers_contract::builders::Event<M, TransferEventFilter> {
+                self.0.event()
+            }
+        });
+    }
     #[test]
     fn expand_transfer_filter() {
         let event = Event {
@@ -420,7 +491,7 @@ mod tests {
 
         let cx = test_context();
         let params = cx.expand_params(&event).unwrap();
-        let name = expand_struct_name(&event);
+        let name = expand_struct_name(&event, None);
         let definition = expand_data_struct(&name, &params);
 
         assert_quote!(definition, {
@@ -431,6 +502,39 @@ mod tests {
         });
     }
 
+    #[test]
+    fn expand_data_struct_with_alias() {
+        let event = Event {
+            name: "Foo".into(),
+            inputs: vec![
+                EventParam {
+                    name: "a".into(),
+                    kind: ParamType::Bool,
+                    indexed: false,
+                },
+                EventParam {
+                    name: String::new(),
+                    kind: ParamType::Address,
+                    indexed: false,
+                },
+            ],
+            anonymous: false,
+        };
+
+        let cx = test_context_with_alias("Foo(bool,address)", "FooAliased");
+        let params = cx.expand_params(&event).unwrap();
+        let alias = Some(util::ident("FooAliased"));
+        let name = expand_struct_name(&event, alias);
+        let definition = expand_data_struct(&name, &params);
+
+        assert_quote!(definition, {
+            struct FooAliasedFilter {
+                pub a: bool,
+                pub p1: ethers_core::types::Address,
+            }
+        });
+    }
+
     #[test]
     fn expand_data_tuple_value() {
         let event = Event {
@@ -452,7 +556,7 @@ mod tests {
 
         let cx = test_context();
         let params = cx.expand_params(&event).unwrap();
-        let name = expand_struct_name(&event);
+        let name = expand_struct_name(&event, None);
         let definition = expand_data_tuple(&name, &params);
 
         assert_quote!(definition, {
@@ -460,6 +564,36 @@ mod tests {
         });
     }
 
+    #[test]
+    fn expand_data_tuple_value_with_alias() {
+        let event = Event {
+            name: "Foo".into(),
+            inputs: vec![
+                EventParam {
+                    name: String::new(),
+                    kind: ParamType::Bool,
+                    indexed: false,
+                },
+                EventParam {
+                    name: String::new(),
+                    kind: ParamType::Address,
+                    indexed: false,
+                },
+            ],
+            anonymous: false,
+        };
+
+        let cx = test_context_with_alias("Foo(bool,address)", "FooAliased");
+        let params = cx.expand_params(&event).unwrap();
+        let alias = Some(util::ident("FooAliased"));
+        let name = expand_struct_name(&event, alias);
+        let definition = expand_data_tuple(&name, &params);
+
+        assert_quote!(definition, {
+            struct FooAliasedFilter(pub bool, pub ethers_core::types::Address);
+        });
+    }
+
     #[test]
     #[rustfmt::skip]
     fn expand_hash_value() {
